This is a simple round-to-multiple function which can be used to voxelize point clouds.
Examples
sphere <- gen_sphere(1, 0.01)
sphere_v <- voxelize(sphere, 0.05)
This is a simple round-to-multiple function which can be used to voxelize point clouds.
sphere <- gen_sphere(1, 0.01)
sphere_v <- voxelize(sphere, 0.05)